@@ -11,10 +11,14 @@
 # under the License.
 
 import itertools
+import six
+import yaml
+
+from django.utils.translation import ugettext_lazy as _
 
 
 def update_pagination(entities, request_size, page_size, marker,
-                      sort_dir, sort_key, reversed_order):
+                      reversed_order):
     has_prev_data = False
     has_more_data = False
 
@@ -38,3 +42,24 @@ def update_pagination(entities, request_size, page_size, marker,
         entities.reverse()
 
     return entities, has_more_data, has_prev_data
+
+
+def convert_to_yaml(data, default_flow_style=False):
+    if not data:
+        return ''
+    try:
+        return yaml.safe_dump(data, default_flow_style=default_flow_style)
+    except Exception:
+        return ''
+
+
+def load_yaml(data):
+    if not data:
+        loaded_data = {}
+    else:
+        try:
+            loaded_data = yaml.safe_load(data)
+        except Exception as ex:
+            raise Exception(_('The specified input is not a valid '
+                              'YAML format: %s') % six.text_type(ex))
+    return loaded_data
